OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "\"config\"ディレクトリに書き込むことは出来ません！",
    "This can usually be fixed by giving the web server write access to the config directory." : "これは通常、Webサーバーにconfigディレクトリへの書き込み権限を与えることで解決できます。",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "しかし、config.phpファイルを読み取り専用にしたい場合は、オプションの \"config_is_read_only\"をtrueに設定してください。",
    "See %s" : "%s を閲覧",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "アプリ %1$s のファイルが正しく置き換えられませんでした。サーバーと互換性のあるバージョンであることを確認してください。",
    "Sample configuration detected" : "サンプル設定が見つかりました。",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "サンプル設定がコピーされてそのままです。このままではインストールが失敗し、サポート対象外になります。config.phpを変更する前にドキュメントを確認してください。",
    "404" : "404",
    "The page could not be found on the server." : "ページがサーバー上に見つかりませんでした。",
    "%s email verification" : "%sメールによる確認",
    "Email verification" : "メールによる確認",
    "Click the following button to confirm your email." : "下記のボタンをクリックして、メールを確認してください。",
    "Click the following link to confirm your email." : "下記のリンクをクリックして、メールを確認してください。",
    "Confirm your email" : "メールを確認",
    "Other activities" : "その他のアクティビティ",
    "%1$s and %2$s" : "%1$s と %2$s",
    "%1$s, %2$s and %3$s" : "%1$s と %2$s、%3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s と %2$s、%3$s、%4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s と %2$s、%3$s、%4$s、%5$s",
    "Education Edition" : "教育向けエディション",
    "Enterprise bundle" : "エンタープライズ バンドル",
    "Groupware bundle" : "グループウェア バンドル",
    "Hub bundle" : "Hubバンドル",
    "Social sharing bundle" : "SNS バンドル",
    "PHP %s or higher is required." : "PHP %s 以上が必要です。",
    "PHP with a version lower than %s is required." : "%s 以前のバージョンのPHPが必要です。",
    "%sbit or higher PHP required." : "%sbit 以上の新しいバージョンのPHPが必要です。",
    "The following architectures are supported: %s" : "次のアーキテクチャをサポートしています: %s",
    "The following databases are supported: %s" : "次のデータベースをサポートしています: %s",
    "The command line tool %s could not be found" : "コマンド '%s' は見つかりませんでした。",
    "The library %s is not available." : " %s ライブラリーが利用できません。",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "%1$sライブラリーは、%2$sよりも新しいバージョンが必要です。利用可能なバージョンは、 %3$sです。",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "%1$s ライブラリーは、%2$s よりも古いバージョンが必要です。利用可能なバージョンは、%3$s です。",
    "The following platforms are supported: %s" : "次のプラットフォームをサポートしています: %s",
    "Server version %s or higher is required." : "サーバーの %s よりも高いバージョンが必要です。",
    "Server version %s or lower is required." : "サーバーの %s よりも低いバージョンが必要です。",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "この設定にアクセスするには、ログインしたユーザーが管理者、サブ管理者、または特別な権利が必要です。",
    "Logged in user must be an admin or sub admin" : "ログインユーザーは管理者またはサブ管理者である必要があります",
    "Logged in user must be an admin" : "ログインユーザーは管理者である必要があります",
    "Wiping of device %s has started" : "端末%sのワイプを開始しました。",
    "Wiping of device »%s« has started" : "端末»%s«のワイプを開始しました。",
    "»%s« started remote wipe" : "»%s«がリモートワイプを開始しました",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "端末またはアプリケーション»%s«がリモートワイプ処理を開始しました。 プロセスの完了時、電子メールを受信します",
    "Wiping of device %s has finished" : "端末%sのワイプが完了しました",
    "Wiping of device »%s« has finished" : "端末»%s«のワイプが完了しました",
    "»%s« finished remote wipe" : "»%s«のリモートワイプが完了しました",
    "Device or application »%s« has finished the remote wipe process." : "端末またはアプリケーション»%s«のリモートワイプ処理が完了しました。 ",
    "Remote wipe started" : "リモートワイプを開始しました",
    "A remote wipe was started on device %s" : "端末%sでリモートワイプが開始されました",
    "Remote wipe finished" : "リモートワイプが完了しました",
    "The remote wipe on %s has finished" : "%sのリモートワイプが完了しました",
    "Authentication" : "認証",
    "Unknown filetype" : "不明なファイルタイプ",
    "Invalid image" : "無効な画像",
    "Avatar image is not square" : "アバター画像が正方形ではありません",
    "Files" : "ファイル",
    "View profile" : "プロフィールを表示",
    "Local time: %s" : "現地時間: %s",
    "today" : "今日",
    "tomorrow" : "明日",
    "yesterday" : "昨日",
    "_in %n day_::_in %n days_" : ["%n 日"],
    "_%n day ago_::_%n days ago_" : ["%n 日前"],
    "next month" : "来月",
    "last month" : "先月",
    "_in %n month_::_in %n months_" : ["%n ヶ月"],
    "_%n month ago_::_%n months ago_" : ["%n ヶ月前"],
    "next year" : "来年",
    "last year" : "去年",
    "_in %n year_::_in %n years_" : ["%n 年"],
    "_%n year ago_::_%n years ago_" : ["%n 年前"],
    "_in %n hour_::_in %n hours_" : ["%n 時間"],
    "_%n hour ago_::_%n hours ago_" : ["%n 時間前"],
    "_in %n minute_::_in %n minutes_" : ["%n 分"],
    "_%n minute ago_::_%n minutes ago_" : ["%n 分前"],
    "in a few seconds" : "数秒",
    "seconds ago" : "数秒前",
    "Empty file" : "空白のファイル",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "ID: %sのモジュールは存在しません。アプリ設定で有効にするか、管理者に問い合わせてください。",
    "File already exists" : "ファイルが既に存在します",
    "Invalid path" : "パスが無効",
    "Failed to create file from template" : "テンプレートからファイルを作成できませんでした",
    "Templates" : "テンプレート",
    "File name is a reserved word" : "ファイル名が予約された単語です",
    "File name contains at least one invalid character" : "ファイル名に1文字以上の無効な文字が含まれています",
    "File name is too long" : "ファイル名が長すぎます",
    "Dot files are not allowed" : "隠しファイルは許可されていません",
    "Empty filename is not allowed" : "空のファイル名は許可されていません",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "appinfoファイルが読み込めないため、アプリ名 \"%s\"  がインストールできません。",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "\"%s\" アプリは、このバージョンのサーバーと互換性がないためインストールされませんでした。",
    "__language_name__" : "Japanese (日本語)",
    "This is an automatically sent email, please do not reply." : "これは自動的に生成されたメールです。返信しないでください。",
    "Help" : "ヘルプ",
    "Appearance and accessibility" : "外観とアクセシビリティ",
    "Apps" : "アプリ",
    "Personal settings" : "個人設定",
    "Administration settings" : "管理者設定",
    "Settings" : "設定",
    "Log out" : "ログアウト",
    "Users" : "ユーザー",
    "Email" : "メール",
    "Mail %s" : "メール %s",
    "Fediverse" : "フェディバース",
    "View %s on the fediverse" : "%sをフェディバース上で見る",
    "Phone" : "携帯",
    "Call %s" : "電話 %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Twitterで%sを表示",
    "Website" : "ウェブサイト",
    "Visit %s" : "訪問先 %s",
    "Address" : "アドレス",
    "Profile picture" : "プロフィールの写真",
    "About" : "詳細",
    "Full name" : "フルネーム",
    "Headline" : "見出し",
    "Organisation" : "組織",
    "Role" : "ロール",
    "Unknown user" : "不明なユーザー",
    "Additional settings" : "追加設定",
    "Enter the database username and name for %s" : "%sのデータベース名とユーザー名を入力してください",
    "Enter the database username for %s" : "%sのデータベースのユーザー名を指定してください",
    "Enter the database name for %s" : "%sのデータベース名を指定してください",
    "You cannot use dots in the database name %s" : "データベース名%sにドットを入れることはできません",
    "MySQL username and/or password not valid" : "MySQLのユーザー名またはパスワードが有効ではありません",
    "You need to enter details of an existing account." : "既存のアカウントの詳細を入力してください。",
    "Oracle connection could not be established" : "Oracleへの接続が確立できませんでした。",
    "Oracle username and/or password not valid" : "Oracleのユーザー名またはパスワードが有効ではありません",
    "PostgreSQL username and/or password not valid" : "PostgreSQLのユーザー名またはパスワードが有効ではありません",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X では、サポートされていません。このOSでは、%sは正常に動作しないかもしれません。ご自身の責任においてご利用ください。",
    "For the best results, please consider using a GNU/Linux server instead." : "最も良い方法としては、代わりにGNU/Linuxサーバーを利用することをご検討ください。",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "このインスタンス %s は、32bit PHP 環境で動作しており、php.ini に open_basedir が設定されているようです。4GB以上のファイルで問題が発生するため、この設定を利用しないことをお勧めします。",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "php.ini から open_basedir 設定を削除するか、64bit PHPに切り替えてください。",
    "Set an admin username." : "管理者のユーザー名を設定",
    "Set an admin password." : "管理者のパスワードを設定",
    "Cannot create or write into the data directory %s" : " データディレクトリ%sに作成、書き込みができません",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "%s のバックエンドの共有には、OCP\\Share_Backend インターフェースを実装しなければなりません。",
    "Sharing backend %s not found" : "共有バックエンド %s が見つかりません",
    "Sharing backend for %s not found" : "%s のための共有バックエンドが見つかりません",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s さんが »%2$s« にノートを追加しました。",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s shared »%2$s« with you and wants to add",
    "»%s« added a note to a file shared with you" : "»%s« があなたと共有しているファイルにノートを追加しました。 ",
    "Open »%s«" : "»%s«を開く",
    "%1$s via %2$s" : "%1$s via %2$s",
    "You are not allowed to share %s" : "%s を共有することを許可されていません。",
    "Cannot increase permissions of %s" : "%sの権限を追加できません ",
    "Files cannot be shared with delete permissions" : "削除権限付きでファイルを共有できません",
    "Files cannot be shared with create permissions" : "作成権限付きでファイルを共有できません",
    "Expiration date is in the past" : "有効期限が切れています",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["%s 日以上先の有効期限は設定できません "],
    "Sharing is only allowed with group members" : "共有はグループメンバーにのみ許可されます",
    "Sharing %s failed, because this item is already shared with user %s" : "このアイテム%sはすでにユーザー%sと共有されているため、共有に失敗しました",
    "%1$s shared »%2$s« with you" : "%1$s は »%2$s« をあなたと共有しました",
    "%1$s shared »%2$s« with you." : "%1$sが あなたと »%2$s« を共有しました。",
    "Click the button below to open it." : "開くには下のボタンをクリック",
    "The requested share does not exist anymore" : "この共有はもう存在しません。",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "登録可能なユーザー数の上限に達したため、ユーザーは作成されませんでした。詳細については通知をご確認ください。",
    "Could not find category \"%s\"" : "カテゴリ \"%s\" が見つかりませんでした",
    "Sunday" : "日曜日",
    "Monday" : "月曜日",
    "Tuesday" : "火曜日",
    "Wednesday" : "水曜日",
    "Thursday" : "木曜日",
    "Friday" : "金曜日",
    "Saturday" : "土曜日",
    "Sun." : "日",
    "Mon." : "月",
    "Tue." : "火",
    "Wed." : "水",
    "Thu." : "木",
    "Fri." : "金",
    "Sat." : "土",
    "Su" : "日",
    "Mo" : "月",
    "Tu" : "火",
    "We" : "水",
    "Th" : "木",
    "Fr" : "金",
    "Sa" : "土",
    "January" : "1月",
    "February" : "2月",
    "March" : "3月",
    "April" : "4月",
    "May" : "5月",
    "June" : "6月",
    "July" : "7月",
    "August" : "8月",
    "September" : "9月",
    "October" : "10月",
    "November" : "11月",
    "December" : "12月",
    "Jan." : "1月",
    "Feb." : "2月",
    "Mar." : "3月",
    "Apr." : "4月",
    "May." : "5月",
    "Jun." : "6月",
    "Jul." : "7月",
    "Aug." : "8月",
    "Sep." : "9月",
    "Oct." : "10月",
    "Nov." : "11月",
    "Dec." : "12月",
    "A valid password must be provided" : "有効なパスワードを指定する必要があります",
    "The username is already being used" : "このユーザー名はすでに使われています",
    "Could not create user" : "ユーザーを作成できませんでした",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "ユーザー名で利用できる文字列： \"a-z\", \"A-Z\", \"0-9\", スペース, \"_.@-\"",
    "A valid username must be provided" : "有効なユーザー名を指定する必要があります",
    "Username contains whitespace at the beginning or at the end" : "ユーザー名の最初か最後に空白が含まれています",
    "Username must not consist of dots only" : "ユーザー名に、ドットのみはつけられません",
    "Username is invalid because files already exist for this user" : "このユーザーのファイルが既に存在するため、このユーザー名は使用できません",
    "User disabled" : "ユーザーは無効です",
    "Login canceled by app" : "アプリによりログインが中止されました",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "次の依存関係を満たしていないため、アプリ \"%1$s\" をインストールできません: %2$s",
    "a safe home for all your data" : "すべてのデータを安全に保管します",
    "File is currently busy, please try again later" : "現在ファイルはビジーです。後でもう一度試してください。",
    "Cannot download file" : "ファイルをダウンロードできません",
    "Application is not enabled" : "アプリケーションは無効です",
    "Authentication error" : "認証エラー",
    "Token expired. Please reload page." : "トークンが無効になりました。ページを再読込してください。",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "データベースドライバー (sqlite, mysql, postgresql) がインストールされていません。",
    "Cannot write into \"config\" directory." : "\"config\" ディレクトリに書き込みできません",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "これは通常、Webサーバーの configディレクトリ に書き込み権限を与えることで解決できます。%s を見てください",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "またはconfig.phpファイルを読み取り専用にしたい場合は、オプション \"config_is_read_only\"をtrueに設定してください。 詳しくは%sを確認してください。",
    "Cannot write into \"apps\" directory." : "\"apps\" ディレクトリに書き込みができません",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "これは通常、Webサーバーにappsディレクトリへの書き込み権限を許可するか、構成ファイルでAppStoreを無効にすることで解決できます。",
    "Cannot create \"data\" directory." : "dataディレクトリを作成できません。",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "これは通常、ウェブサーバーにルートディレクトリへの書き込み権限を与えることで解決できます。詳しくは%sを確認してください。",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Webサーバーのルートディレクトリに書き込み権限パーミッションが必要です。詳しくは%sを確認してください。",
    "Your data directory is not writable." : "データディレクトリに書き込み権がありません",
    "Setting locale to %s failed." : "ロケールを %s に設定できませんでした",
    "Please install one of these locales on your system and restart your web server." : "これらのロケールのうちいずれかをシステムにインストールし、Webサーバーを再起動してください。",
    "PHP module %s not installed." : "PHP のモジュールの %s がインストールされていません。",
    "Please ask your server administrator to install the module." : "サーバー管理者にモジュールのインストールを依頼してください。",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP設定の\"%s\"が \"%s\"に設定されていません",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "php.ini のこの設定を調整して、再度 Nextcloudを起動してください。",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code>の値は <code>0</code>であるべきですが、<code>%s</code> に設定されています。",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "この問題を修正するには、php.ini ファイルの <code>mbstring.func_overload</code> を <code>0</code> に設定してください。",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 バージョン 2.7.0 が最低必要です。現在 %s がインストールされています。",
    "To fix this issue update your libxml2 version and restart your web server." : "この問題を解決するには、libxml2 を更新して、Webサーバーを再起動してください。",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHPでインラインドキュメントブロックを取り除く設定になっています。これによりコアアプリで利用できないものがいくつかあります。",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "これは、Zend OPcacheやeAccelerator 等のキャッシュ/アクセラレーターが原因かもしれません。",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP モジュールはインストールされていますが、まだ一覧に表示されていますか？",
    "Please ask your server administrator to restart the web server." : "サーバー管理者にWebサーバーを再起動するよう依頼してください。",
    "The required %s config variable is not configured in the config.php file." : "必要な %s 構成変数が config.php ファイルに設定されていません。",
    "Please ask your server administrator to check the Nextcloud configuration." : "サーバー管理者にNextcloud構成を確認するように依頼してください。",
    "PostgreSQL >= 9 required." : "PostgreSQL 9以上が必要です",
    "Please upgrade your database version." : "新しいバージョンのデータベースにアップグレードしてください。",
    "Your data directory is readable by other users." : "データディレクトリは他のユーザーからも読み取ることができます",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "ディレクトリが他のユーザーから見えないように、パーミッションを 0770 に変更してください。",
    "Your data directory must be an absolute path." : "データディレクトリは、絶対パスにする必要があります",
    "Check the value of \"datadirectory\" in your configuration." : "設定ファイル内の \"datadirectory\" の値を確認してください。",
    "Your data directory is invalid." : "データディレクトリが無効です",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "データディレクトリの直下に \".ocdata\" ファイルがあるのを確認してください。",
    "Action \"%s\" not supported or implemented." : "アクション「%s」は対応していないか、実装されていません。",
    "Authentication failed, wrong token or provider ID given" : "認証できませんでした。トークンまたはプロバイダーIDが間違っています",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "要求を完了するためのパラメータがありません。欠落したパラメータ:「%s」",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID｢%1$s｣はクラウドフェデレーションプロバイダー｢%2$s｣によって既に使用されています",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "ID: \"%s\"のクラウドフェデレーションプロバイダーは存在しません。",
    "Could not obtain lock type %d on \"%s\"." : "\"%s\" で %d タイプのロックを取得できませんでした。",
    "Storage unauthorized. %s" : "権限のないストレージです。 %s",
    "Storage incomplete configuration. %s" : "設定が未完了のストレージです。 %s",
    "Storage connection error. %s" : "ストレージへの接続エラー｡ %s",
    "Storage is temporarily not available" : "ストレージは一時的に利用できません",
    "Storage connection timeout. %s" : "ストレージへの接続がタイムアウト。 %s",
    "%s enter the database username and name." : "%s データベース名とデータベースのユーザー名を入力してください。",
    "%s enter the database username." : "%s のデータベースのユーザー名を入力してください。",
    "%s enter the database name." : "%s のデータベース名を入力してください。",
    "%s you may not use dots in the database name" : "%s ではデータベース名にドットを利用できないかもしれません。",
    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "ユーザー制限に達したため、ユーザーは作成されませんでした。詳細については、通知を確認してください。",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "ユーザー名で利用できる文字列： \"a-z\", \"A-Z\", \"0-9\", \"_.@-\""
},
"nplurals=1; plural=0;");
